export function randomExtend (minNum, maxNum) {
  if (arguments.length === 1) {
    return parseInt(Math.random() * minNum + 1, 10)
  } else {
    return parseInt(Math.random() * (maxNum - minNum + 1) + minNum, 10)
  }
}

export function debounce (delay, callback) {
  let lastTime

  return function () {
    clearTimeout(lastTime)

    const [that, args] = [this, arguments]

    lastTime = setTimeout(() => {
      callback.apply(that, args)
    }, delay)
  }
}

export function observerDomResize (dom, callback) {
  const MutationObserver = window.MutationObserver || window.WebKitMutationObserver || window.MozMutationObserver

  const observer = new MutationObserver(callback)

  observer.observe(dom, { attributes: true, attributeFilter: ['style'], attributeOldValue: true })

  return observer
}

export function getPointDistance (pointOne, pointTwo) {
  const minusX = Math.abs(pointOne[0] - pointTwo[0])

  const minusY = Math.abs(pointOne[1] - pointTwo[1])

  return Math.sqrt(minusX * minusX + minusY * minusY)
}
export function deepMerge (target, merged) {
  for (var key in merged) {
    // eslint-disable-next-line no-undef
    if (target[key] && (0, _typeof2['default'])(target[key]) === 'object') {
      deepMerge(target[key], merged[key])
      continue
    }

    // eslint-disable-next-line no-undef
    if ((0, _typeof2['default'])(merged[key]) === 'object') {
      // eslint-disable-next-line no-undef
      target[key] = (0, _util.deepClone)(merged[key], true)
      continue
    }

    target[key] = merged[key]
  }

  return target
}

export function deepClone (object) {
  var recursion = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false
  if (!object) return object
  // eslint-disable-next-line one-var
  var parse = JSON.parse,
    stringify = JSON.stringify
  if (!recursion) return parse(stringify(object))
  var clonedObj = object instanceof Array ? [] : {}

  // eslint-disable-next-line no-undef
  if (object && (0, _typeof2['default'])(object) === 'object') {
    for (var key in object) {
      if (object.hasOwnProperty(key)) {
        // eslint-disable-next-line no-undef
        if (object[key] && (0, _typeof2['default'])(object[key]) === 'object') {
          clonedObj[key] = deepClone(object[key], true)
        } else {
          clonedObj[key] = object[key]
        }
      }
    }
  }

  return clonedObj
}

export function uuid (hasHyphen) {
  return (hasHyphen ? 'xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx' : 'xxxxxxxxxxxx4xxxyxxxxxxxxxxxxxxx').replace(/[xy]/g, function (c) {
    const r = Math.random() * 16 | 0
    const v = c === 'x' ? r : (r & 0x3 | 0x8)
    return v.toString(16)
  })
}

// function getRgbValue (color) {
//   if (!color) {
//     console.error('getRgbValue: Missing parameters!')
//     return false
//   }
//
//   color = validator(color)
//   if (!color) return false
//   var isHex = hexReg.test(color)
//   var isRgb = rgbReg.test(color)
//   var lowerColor = color.toLowerCase()
//   if (isHex) return getRgbValueFromHex(lowerColor)
//   if (isRgb) return getRgbValueFromRgb(lowerColor)
// }
// export function fade (color) {
//   var percent = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 100
//
//   if (!color) {
//     console.error('fade: Missing parameters!')
//     return false
//   }
//
//   var rgbValue = getRgbValue(color)
//   if (!rgbValue) return false
//   var rgbaValue = [].concat((0, _toConsumableArray2['default'])(rgbValue), [percent / 100])
//   return getColorFromRgbValue(rgbaValue)
// }
