/**
 * @author  daya
 * @createDate  2021/10/29 15:45
 * 备注: 地图设置
 **/
// 按需引入,charts很多东西的
// eslint-disable-next-line no-unused-vars,no-redeclare
import {defaultColor, defaultFontSize, formatToMillion, linearGradientStyle, labelStyle, tooltipStyle, horizontalDataZoom, verticalDataZoom} from '../../charts'

// TODO:如果需要用到字体样式的话把这个打开
// 文字样式
// eslint-disable-next-line no-unused-vars
const fontStyle = {
  color: defaultColor,
  fontSize: defaultFontSize
}
// 散点图样式1
const scatterStyle1 = {
  type: 'scatter',
  coordinateSystem: 'geo',
  symbol: 'pin',
  symbolSize: 60,
  itemStyle: {
    color: '#3db9ef',
    shadowColor: '#0a1223',
    shadowBlur: 6
    // borderColor: 'rgba(34,56,100,0.7)',
    // borderWidth: 0.2
  },
  label: {
    show: true,
    position: 'bottom',
    distance: 0,
    offset: [0, -45],
    formatter: lb => {
      return lb.value[2] + '\n人'
    },
    textStyle: {
      color: '#fff',
      fontSize: defaultFontSize,
      backgroundColor: 'transparent',
      textAlign: 'center'
    }
  },
  z: 20,
  data: [
    {
      name: '南山2',
      value: [109.915395, 20.879016, 200]
    },
    {
      name: '除闻',
      value: [110.182156, 20.311647, 195.56]
    }, {
      name: '除闻33',
      value: [110.282191, 21.30205, 237]
    }
  ]
}

// 散点和飞线图
const scatterStyle2 = [
  {
    name: '',
    type: 'effectScatter',
    coordinateSystem: 'geo',
    data: [],
    symbolSize: 10,
    showEffectOn: 'render',
    rippleEffect: {
      brushType: 'stroke'
    },
    hoverAnimation: true,
    label: {
      normal: {
      // formatter: '{b}',
        formatter: function (params) {
          return params.name
        },
        // color: 'rgba(77, 255, 143, 1)',
        color: '#5bffa7',
        position: 'top',
        show: true
      }
    },
    itemStyle: {
      normal: {
        color: '#9beff3',
        shadowBlur: 10,
        shadowColor: '#333'
      }
    },
    z: 21
  },
  {
    name: '',
    type: 'lines',
    silent: true,
    coordinateSystem: 'geo',
    effect: {
      show: true,
      period: 6,
      // trailLength: 1,
      trailLength: 0.6,
      color: '#9beff3', // 移动箭头颜色
      // color: 'red', // 移动箭头颜色
      symbol: 'triangle',
      symbolSize: 6
    },
    lineStyle: {
    // normal: {
      color: '#9beff3',
      width: 2,
      opacity: 0.4,
      // opacity: 1,
      curveness: 0
    // }
    },
    z: 20,
    data: []
  }]

// 散点图样式3
const scatterStyle3 = {
  name: '',
  type: 'effectScatter',
  coordinateSystem: 'geo',
  symbolSize: 10,
  showEffectOn: 'render',
  rippleEffect: {
    brushType: 'stroke'
  },
  hoverAnimation: true,
  label: {
    normal: {
      show: false,
      formatter: function (params) {
        return params.name
      },
      color: '#5bffa7',
      position: 'top'
    }
  },
  itemStyle: {
    color: '#9beff3',
    shadowBlur: 10,
    shadowColor: '#333'
  },
  emphasis: {
    itemStyle: {
      color: '#d8e532'
    }
  },
  z: 20,
  data: [],
  tooltip: {
    padding: 0,
    formatter: params => {
      let topNum = params.dataIndex + 1 || 0
      let rate = params.value.length ? params.value[2] : 0
      let temp = `
        <div class="tooltip">
          <div>
            <span class="tooltip-title">转化率排名</span>
            <span class="tx-yellow">TOP ${topNum}</span>
          </div>
          <div>
            <span class="tooltip-title">${params.name}</span>
            <span class="tx-yellow">${rate}%</span>
          </div>
        </div>`
      return temp
    }
  }
}

// 散点图样式4
const scatterStyle4 = {
  ...scatterStyle3,
  tooltip: {
    padding: 0,
    formatter: params => {
      let topNum = params.data.ranking
      let data = params.value.length ? params.value[2] : 0
      let temp = `
        <div class="tooltip">
          <div>
            <span class="tooltip-title">东三省实时客流排名</span>
            <span class="tx-yellow">TOP ${topNum}</span>
          </div>
          <div>
            <span class="tooltip-title">${params.name}</span>
            <span class="tx-yellow">${data} 人</span>
          </div>
        </div>`
      return temp
    }
  }
}

// 散点图样式5
const scatterStyle5 = {
  ...scatterStyle3,
  tooltip: {
    padding: 0,
    formatter: params => {
      let complaintCount = params.data.complaintCount
      let consultCount = params.data.consultCount
      let temp = `
        <div class="tooltip">
          <div class="tx-center">
            <span>${params.name}</span>
          </div>
          <div>
            <span class="tooltip-title">投诉 <span class="tx-yellow">${complaintCount}</span></span>
            咨询 <span class="tx-yellow">${consultCount}</span>
          </div>
        </div>`
      return temp
    }
  }
}

// 散点图样式6
const scatterStyle6 = {
  type: 'scatter',
  coordinateSystem: 'geo',
  symbolSize: 10,
  showEffectOn: 'render',
  rippleEffect: {
    brushType: 'stroke'
  },
  itemStyle: {
    color: '#9beff3',
    shadowBlur: 10,
    shadowColor: '#333'
  },
  z: 20,
  data: [
    {
      name: '南山2',
      value: [109.915395, 20.879016, 200]
    },
    {
      name: '除闻',
      value: [110.182156, 20.311647, 195.56]
    }, {
      name: '除闻33',
      value: [110.282191, 21.30205, 237]
    }
  ]
}

const optionStyle1 = {
  tooltip: {
    trigger: 'item',
    transitionDuration: 0.4,
    backgroundColor: 'rgba(0,0,0,0.3)',
    padding: [10, 15, 15, 20],
    textStyle: {
      color: defaultColor,
      fontSize: defaultFontSize
    },
    formatter: params => {
      return params.marker + params.name + '：' + params.value[2]
    }
  },
  geo: [{
    map: 'city',
    z: 1,
    aspectScale: 1.2,
    // scaleLimit: {
    //   min: 1.15,
    //   max: 1.15
    // },
    itemStyle: {
      // areaColor: '#597dca',
      areaColor: 'rgba(72,98,182,0.6)',
      borderColor: '#5776c2',
      // color: '#5475be',
      borderWidth: 1.5,
      // shadowColor: '#425b90',
      shadowColor: '#213169',
      // shadowBlur: 10,
      shadowOffsetX: 6,
      shadowOffsetY: 10
    }
  }, {
    map: 'city',
    z: 11,
    aspectScale: 1.2,
    // scaleLimit: {
    //   min: 1.15,
    //   max: 1.15
    // },
    label: {
      show: true,
      color: '#73a2cd',
      fontSize: 12
    },
    itemStyle: {
      // areaColor: '#597dca',
      areaColor: 'rgba(62, 91, 166, 0.85)',
      // borderColor: '#4a67a5',
      borderColor: '#5475bc',
      // color: '#5475be',
      borderWidth: 1.5
    },
    emphasis: {
      label: {
        color: '#98b3f5',
        fontSize: '100%'
      },
      itemStyle: {
        areaColor: '#597dca'
      }
    }
  }],
  series: [
    // {
    //   type: 'scatter',
    //   coordinateSystem: 'geo',
    //   symbol: 'pin',
    //   symbolSize: 60,
    //   itemStyle: {
    //     color: '#3db9ef',
    //     shadowColor: '#0a1223',
    //     shadowBlur: 6
    //     // borderColor: 'rgba(34,56,100,0.7)',
    //     // borderWidth: 0.2
    //   },
    //   label: {
    //     show: true,
    //     position: 'bottom',
    //     distance: 0,
    //     offset: [0, -45],
    //     formatter: lb => {
    //       return lb.value[2] + '\n人'
    //     },
    //     textStyle: {
    //       color: '#fff',
    //       fontSize: defaultFontSize,
    //       backgroundColor: 'transparent',
    //       textAlign: 'center',
    //     },
    //   },
    //   z: 20,
    //   data: [
    //     {
    //       name: '南山2',
    //       value: [109.915395,20.879016, 200]
    //     },
    //     {
    //       name: '除闻',
    //       value: [110.182156,20.311647, 195.56]
    //     },{
    //       name: '除闻33',
    //       value: [110.282191,21.30205, 237]
    //     }
    //   ]
    // }
  ]
}

export const optStyle = {
  optionStyle1
}

export const scatterStyle = {
  scatterStyle1, scatterStyle2, scatterStyle3, scatterStyle4, scatterStyle5, scatterStyle6
}
